<!-- Hot cache list partial - refreshable via HTMX -->
{% if memories %}
    {% for memory in memories %}
        {% set is_pinned = memory.is_pinned %}
        {% include "partials/hot_item.html" %}
    {% endfor %}
{% else %}
    <div class="bg-dark-900 rounded-lg border border-gray-800 p-8 text-center">
        <svg class="w-12 h-12 text-gray-600 mx-auto mb-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M13 10V3L4 14h7v7l9-11h-7z"/>
        </svg>
        <p class="text-gray-400">No memories in hot cache</p>
        <p class="text-gray-500 text-sm mt-1">Promote memories from the browser or let auto-promotion do its work</p>
    </div>
{% endif %}
